@@ -1,15 +1,20 @@
 import sqlalchemy as db
 
-from dagster import check
+import dagster._check as check
 from dagster.core.storage.event_log import (
     AssetKeyTable,
     SqlEventLogStorage,
     SqlEventLogStorageMetadata,
     SqlPollingEventWatcher,
 )
+from dagster.core.storage.event_log.base import EventLogCursor
 from dagster.core.storage.event_log.migration import ASSET_KEY_INDEX_COLS
-from dagster.core.storage.sql import stamp_alembic_rev  # pylint: disable=unused-import
-from dagster.core.storage.sql import create_engine, run_alembic_upgrade
+from dagster.core.storage.sql import (
+    check_alembic_revision,
+    create_engine,
+    run_alembic_upgrade,
+    stamp_alembic_rev,
+)
 from dagster.serdes import ConfigurableClass, ConfigurableClassData
 
 from ..utils import (
@@ -22,8 +27,6 @@ from ..utils import (
     retry_mysql_creation_fn,
 )
 
-CHANNEL_NAME = "run_events"
-
 
 class MySQLEventLogStorage(SqlEventLogStorage, ConfigurableClass):
     """MySQL-backed event log storage.
@@ -123,18 +126,27 @@ class MySQLEventLogStorage(SqlEventLogStorage, ConfigurableClass):
         # See SqlEventLogStorage.store_asset_event method for more details
 
         values = self._get_asset_entry_values(event, self.has_secondary_index(ASSET_KEY_INDEX_COLS))
-
         with self.index_connection() as conn:
-            conn.execute(
-                db.dialects.mysql.insert(AssetKeyTable)
-                .values(
-                    asset_key=event.dagster_event.asset_key.to_string(),
-                    **values,
+            if values:
+                conn.execute(
+                    db.dialects.mysql.insert(AssetKeyTable)
+                    .values(
+                        asset_key=event.dagster_event.asset_key.to_string(),
+                        **values,
+                    )
+                    .on_duplicate_key_update(
+                        **values,
+                    )
                 )
-                .on_duplicate_key_update(
-                    **values,
-                )
-            )
+            else:
+                try:
+                    conn.execute(
+                        db.dialects.mysql.insert(AssetKeyTable).values(
+                            asset_key=event.dagster_event.asset_key.to_string(),
+                        )
+                    )
+                except db.exc.IntegrityError:
+                    pass
 
     def _connect(self):
         return create_mysql_connection(self._engine, __file__, "event log")
@@ -157,8 +169,10 @@ class MySQLEventLogStorage(SqlEventLogStorage, ConfigurableClass):
         if name in self._secondary_index_cache:
             del self._secondary_index_cache[name]
 
-    def watch(self, run_id, start_cursor, callback):
-        self._event_watcher.watch_run(run_id, start_cursor, callback)
+    def watch(self, run_id, cursor, callback):
+        if cursor and EventLogCursor.parse(cursor).is_offset_cursor():
+            check.failed("Cannot call `watch` with an offset cursor")
+        self._event_watcher.watch_run(run_id, cursor, callback)
 
     def end_watch(self, run_id, handler):
         self._event_watcher.unwatch_run(run_id, handler)
@@ -174,3 +188,8 @@ class MySQLEventLogStorage(SqlEventLogStorage, ConfigurableClass):
         if not self._disposed:
             self._disposed = True
             self._event_watcher.close()
+
+    def alembic_version(self):
+        alembic_config = mysql_alembic_config(__file__)
+        with self._connect() as conn:
+            return check_alembic_revision(alembic_config, conn)
